/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include <dawn/dawn.h>
#include "pokergameassets.h"
#include "../../poker/poker.h"
#include "../../vn/conversation/talk.h"
#include "../../vn/vnscene.h"
#include "../../util/array.h"
#include "actions/start.h"
#include "ui/pokerui.h"
#include "pokerworld.h"
#include "actions/start.h"

/**
 * Initializes the game state for the poker game.
 * 
 * @param game Game to initialize.
 * @returns True if successful, otherwise false.
 */
bool pokerGameInit(pokergame_t *game);

/**
 * Updates the poker game instance.
 * @param game Poker game to update for.
 * @param engine Engine to use during update.
 */
void pokerGameUpdate(pokergame_t *game, engine_t *engine);

/**
 * Disposes a previously initialized poker game instance.
 * @param game Game to dispose.
 */
void pokerGameDispose(pokergame_t *game);

/**
 * Restacks the poker game's stack.
 * 
 * @param pokerGame Poker game to restack
 */
void pokerGameQueueRestack(pokergame_t *pokerGame);